@@ -1,6 +1,7 @@
 """
-A child class to simulate raw data of conventional Sim. @author: Meizhu Liang @Imperial College
+A child class to simulate raw data of conventional Sim.
 """
+__author__ = "Meizhu Liang @Imperial College London"
 
 from napari_generic_simulator.baseSIMulator import Base_simulator
 import numpy as np
